@@ -13,13 +13,17 @@ class DataclassType(Enum):
 class ClassMeta:
     name: str
     _type: DataclassType
+    has_validators: bool
     alias_name: str = field(default_factory=lambda: f"_{uuid4().hex}")
 
     @classmethod
     def from_class(cls, clazz: Any):
+        _type = get_dataclass_type(clazz)
+
         return cls(
             name=clazz.__name__,
-            _type=get_dataclass_type(clazz),
+            _type=_type,
+            has_validators=has_validators(clazz, _type)
         )
 
 
@@ -33,3 +37,11 @@ def get_dataclass_type(cls: Any) -> DataclassType:
     except ImportError:
         pass
     raise NotImplementedError("only dataclasses and pydantic classes are supported")
+
+
+def has_validators(cls: Any, _type: DataclassType) -> bool:
+    if _type == DataclassType.DATACLASSES:
+        return False
+    elif _type == DataclassType.PYDANTIC:
+        return bool(cls.__validators__) or bool(cls.__pre_root_validators__) or bool(cls.__post_root_validators__)
+    raise NotImplementedError("only dataclasses and pydantic classes are supported")
